@@ -1,7 +1,7 @@
 package App::tracepm;
 
 our $DATE = '2015-04-15'; # DATE
-our $VERSION = '0.16'; # VERSION
+our $VERSION = '0.17'; # VERSION
 
 use 5.010001;
 use strict;
@@ -120,17 +120,23 @@ _
             pos => 1,
             greedy => 1,
         },
-        multiple_args => {
+        multiple_runs => {
             # XXX add args_rels: conflict with args
-            summary => 'A set of args, run script multiple times',
-            schema => ['array*' => of => ['array*' => of => 'str*']],
+            summary => 'Parameter to run script multiple times',
+            schema => ['array*' => of => 'hash*'],
             description => <<'_',
 
-An alternative to using `args`. Script will be run multiple times, each with a
-set of args from this.
+A more general alternative to using `args`. Script will be run multiple times,
+each with setting from element of this option.
 
 Can be used to reach multiple run pathways and trace more modules.
 
+Example:
+
+    [{"args":["-h"]}, # help mode
+     {"args":[""], "env":{"COMP_LINE":"cmd x", "COMP_POINT":5}},
+    ],
+
 _
         },
         perl_version => {
@@ -232,14 +238,33 @@ sub tracepm {
         } else {
             # 'require' method
             $routine = sub {
-                my @args_sets = $args{multiple_args} ?
-                    @{ $args{multiple_args} } : ($args{args});
-                local $App::tracepm::Tracer::APPEND_MODE = 1;
-                for my $args (@args_sets) {
+                if ($args{multiple_runs}) {
+                    local $ENV{TRACEPM_TRACER_APPEND} = 1;
+                    for my $run (@{ $args{multiple_runs} }) {
+                        my $save_env;
+                        if ($run->{env}) {
+                            $save_env = {};
+                            for (keys %{ $run->{env} }) {
+                                $save_env->{$_} = $ENV{$_};
+                                $ENV{$_} = $run->{env}{$_};
+                            }
+                        }
+                        system($^X,
+                               "-MApp::tracepm::Tracer=$outf",
+                               (map {"-M$_"} @{$args{use} // []}),
+                               $script, @{$run->{args} // []},
+                           );
+                        if ($save_env) {
+                            for (keys %$save_env) {
+                                $ENV{$_} = $save_env->{$_};
+                            }
+                        }
+                    }
+                } else {
                     system($^X,
                            "-MApp::tracepm::Tracer=$outf",
                            (map {"-M$_"} @{$args{use} // []}),
-                           $script, @{$args // []},
+                           $script, @{$args{args} // []},
                        );
                 }
             };
@@ -414,7 +439,7 @@ App::tracepm - Trace dependencies of your Perl script
 
 =head1 VERSION
 
-This document describes version 0.16 of App::tracepm (from Perl distribution App-tracepm), released on 2015-04-15.
+This document describes version 0.17 of App::tracepm (from Perl distribution App-tracepm), released on 2015-04-15.
 
 =head1 SYNOPSIS
 
@@ -490,15 +515,21 @@ faster.
 
 =back
 
-=item * B<multiple_args> => I<array[array[str]]>
+=item * B<multiple_runs> => I<array[hash]>
 
-A set of args, run script multiple times.
+Parameter to run script multiple times.
 
-An alternative to using C<args>. Script will be run multiple times, each with a
-set of args from this.
+A more general alternative to using C<args>. Script will be run multiple times,
+each with setting from element of this option.
 
 Can be used to reach multiple run pathways and trace more modules.
 
+Example:
+
+ [{"args":["-h"]}, # help mode
+  {"args":[""], "env":{"COMP_LINE":"cmd x", "COMP_POINT":5}},
+ ],
+
 =item * B<perl_version> => I<str>
 
 Perl version, defaults to current running version.
