@@ -1,9 +1,7 @@
 package App::tracepm::Tracer;
 
 our $DATE = '2015-04-15'; # DATE
-our $VERSION = '0.16'; # VERSION
-
-our $APPEND_MODE = 0;
+our $VERSION = '0.17'; # VERSION
 
 # saving CORE::GLOBAL::require doesn't work
 my $orig_require;
@@ -24,7 +22,8 @@ sub import {
     my $file = shift
         or die "Usage: use App::tracerpm::Tracer '/path/to/output'";
 
-    open my($fh), ($APPEND_MODE?">>":">"), $file or die "Can't open $file: $!";
+    open my($fh), ($ENV{TRACEPM_TRACER_APPEND} ? ">>":">"),
+        $file or die "Can't open $file: $!";
 
     #$orig_require = \&CORE::GLOBAL::require;
     *CORE::GLOBAL::require = sub {
@@ -63,7 +62,7 @@ App::tracepm::Tracer - Trace module require to file
 
 =head1 VERSION
 
-This document describes version 0.16 of App::tracepm::Tracer (from Perl distribution App-tracepm), released on 2015-04-15.
+This document describes version 0.17 of App::tracepm::Tracer (from Perl distribution App-tracepm), released on 2015-04-15.
 
 =head1 HOMEPAGE
 
